
#line 3 "scannerlexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 0
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
#if defined(__GNUC__) && __GNUC__ >= 3
__attribute__((__noreturn__))
#endif
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 157
#define YY_END_OF_BUFFER 158
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[979] =
    {   0,
      158,  156,  157,    3,  156,  157,    1,  157,   45,  156,
      157,  156,  157,   20,  156,  157,   40,  156,  157,   42,
      156,  157,  156,  157,   29,  156,  157,   30,  156,  157,
       38,  156,  157,   36,  156,  157,   69,  156,  157,   37,
      156,  157,   35,  156,  157,   39,  156,  157,  149,  156,
      157,  149,  156,  157,   32,  156,  157,   31,  156,  157,
       47,  156,  157,   46,  156,  157,   48,  156,  157,   34,
      156,  157,  105,  146,  156,  157,  105,  146,  156,  157,
      105,  146,  156,  157,  105,  146,  156,  157,  105,  146,
      156,  157,   25,  156,  157,  156,  157,   27,  156,  157,

       41,  156,  157,  105,  146,  156,  157,  105,  146,  156,
      157,  105,  146,  156,  157,  105,  146,  156,  157,  105,
      146,  156,  157,  105,  146,  156,  157,  105,  146,  156,
      157,  105,  146,  156,  157,  105,  146,  156,  157,  105,
      146,  156,  157,  105,  146,  156,  157,  105,  146,  156,
      157,  105,  146,  156,  157,  105,  146,  156,  157,  105,
      146,  156,  157,  105,  146,  156,  157,   21,  156,  157,
       43,  156,  157,   23,  156,  157,   44,  156,  157,    3,
        1,   62,  154,   53,   24,   65,   55,  152,   51,   67,
       49,   68,   50,   70,  150,    4,    6,   52,  150,  148,

      149,  149,  149,  149,   28,   22,   26,   57,   63,   61,
       64,   58,  105,  146,  105,  146,  105,  146,  105,  146,
        2,   54,  105,  146,  105,  146,  105,  146,  105,  146,
      105,  146,  105,  146,  105,  146,  105,  146,  105,  146,
      105,  146,  105,  146,  105,  115,  146,  105,  146,  105,
      146,  105,  146,  105,  146,  105,  146,  105,  146,  105,
      146,  105,  123,  146,  105,  146,  105,  146,  105,  146,
      105,  146,  105,  146,  105,  146,  105,  146,  105,  146,
      105,  146,  105,  146,  105,  146,  105,  146,   56,   66,
       33,  150,    6,  148,  149,  148,  149,  151,  149,  149,

      149,  147,   59,   60,  105,  146,  105,  146,  155,  153,
      105,  146,  105,  146,  105,  146,  105,  146,  105,  146,
      105,  146,  105,  146,  105,  146,  105,  146,  105,  146,
      105,  146,  105,  146,  105,  146,  105,  146,  105,  146,
      105,  106,  146,  105,  146,  105,  146,  105,  146,  105,
      146,  105,  146,  105,  146,  105,  146,  105,  146,  105,
      146,  105,  146,  105,  146,  105,  146,  105,  146,  105,
      121,  146,  105,  146,  105,  146,  105,  125,  146,  105,
      146,  105,  146,  105,  146,  105,  146,  105,  146,  105,
      146,  105,  146,  105,  146,  105,  146,  105,  146,  105,

      146,  105,  146,  105,  146,  105,  146,  105,  146,  105,
      146,  105,  146,  150,  148,  149,  148,  149,  148,  149,
      151,  149,  147,  147,  105,  146,  105,  146,  105,  146,
      101,  105,  146,  105,  146,  105,  146,  105,  146,  105,
      146,  105,  146,  105,  146,  105,  146,  105,  146,  105,
      146,  105,  146,  105,  146,  105,  146,  105,  146,  105,
      146,  105,  146,  105,  146,  105,  146,  105,  107,  146,
      105,  108,  146,  105,  146,  105,  110,  146,  105,  111,
      146,  105,  146,  105,  146,  105,  146,  105,  146,  105,
      117,  146,  105,  118,  146,  105,  146,  105,  146,  105,

      146,  105,  122,  146,  105,  146,  105,  130,  146,  105,
      146,  105,  146,  105,  146,  105,  146,  105,  146,  105,
      146,  105,  146,  105,  146,  105,  146,  103,  105,  146,
      105,  146,  105,  146,  105,  146,  105,  143,  146,  105,
      146,  105,  146,   18,   13,  148,  149,  147,  147,  147,
      102,  105,  146,  105,  146,  105,  146,   91,  105,  146,
      105,  146,   74,  105,  146,  105,  146,  105,  146,  105,
      146,  105,  146,  105,  146,  105,  146,  105,  146,  105,
      146,  105,  146,  105,  146,  105,  146,  105,  146,  105,
      146,  105,  146,   97,  105,  146,  105,  109,  146,  105,

      112,  146,  105,  146,  105,  146,  105,  146,  105,  146,
      104,  105,  146,  105,  120,  146,  105,  146,  105,  146,
      105,  146,  105,  146,  105,  134,  146,  105,  146,  105,
      146,  105,  146,  105,  146,  105,  146,  105,  146,  105,
      141,  146,  105,  146,  105,  146,  105,  145,  146,   15,
      147,  105,  146,  105,  146,  105,  146,  105,  146,  105,
      146,  105,  146,  105,  146,  105,  146,  105,  146,  105,
      146,  105,  146,  105,  146,  105,  146,  105,  146,  105,
      146,  105,  146,  105,  146,  105,  146,  105,  146,  105,
      146,  105,  146,  105,  116,  146,  105,  119,  146,  105,

      124,  146,  105,  146,  105,  146,  105,  133,  146,  105,
      135,  146,  105,  136,  146,  105,  137,  146,  105,  138,
      146,  105,  139,  146,  105,  146,  105,  146,  105,  146,
       14,   16,    5,  105,  146,  105,  146,  105,  146,   75,
      105,  146,  105,  146,   93,  105,  146,   78,  105,  146,
      105,  146,  105,  146,  105,  146,  105,  146,   98,  105,
      146,  105,  146,  105,  146,  105,  146,  105,  146,  105,
      146,  105,  146,  105,  146,  105,  146,  105,  114,  146,
      105,  146,  105,  146,  105,  140,  146,  105,  146,  105,
      146,   12,  105,  146,  105,  146,  105,  146,  105,  146,

      105,  146,  105,  146,   81,  105,  146,  105,  129,  146,
      105,  146,  105,  146,   84,  105,  146,  105,  146,   88,
      105,  146,  105,  146,  105,  146,  105,  113,  146,  105,
      131,  146,  105,  132,  146,  105,  142,  146,  105,  144,
      146,    8,   11,   19,   17,  105,  146,  105,  146,   83,
      105,  146,  105,  146,  105,  146,  105,  146,  105,  146,
      105,  146,   82,  105,  146,  105,  146,  105,  146,   96,
      105,  146,  105,  128,  146,  105,  146,    7,    8,  105,
      146,  105,  146,  105,  146,  105,  146,  105,  146,   80,
      105,  146,  105,  127,  146,   86,  105,  146,   85,  105,

      146,  105,  146,   89,  105,  146,  105,  146,  105,  146,
       77,  105,  146,  105,  146,  105,  146,  105,  126,  146,
      105,  146,  105,  146,  105,  146,  105,  146,  105,  146,
       87,  105,  146,   90,  105,  146,  105,  146,  105,  146,
       76,  105,  146,   95,   79,  105,  146,  105,  146,  105,
      146,   71,  105,  146,  105,  146,  105,  146,  105,  146,
       72,   99,  105,  146,  105,  146,  100,  105,  146,   73,
        9,    9,   12,   10,   10,   11,   94,   92
    } ;

static yyconst flex_int16_t yy_accept[678] =
    {   0,
        1,    1,    1,    2,    4,    7,    9,   12,   14,   17,
       20,   23,   25,   28,   31,   34,   37,   40,   43,   46,
       49,   52,   55,   58,   61,   64,   67,   70,   73,   77,
       81,   85,   89,   93,   96,   98,  101,  104,  108,  112,
      116,  120,  124,  128,  132,  136,  140,  144,  148,  152,
      156,  160,  164,  168,  171,  174,  177,  180,  181,  182,
      183,  183,  184,  184,  184,  184,  184,  184,  184,  184,
      185,  186,  187,  188,  188,  189,  189,  190,  191,  192,
      193,  194,  195,  195,  196,  197,  198,  199,  200,  202,
      203,  203,  204,  205,  205,  206,  207,  208,  209,  210,

      211,  212,  213,  215,  217,  219,  219,  219,  221,  222,
      223,  225,  227,  229,  231,  233,  235,  237,  239,  241,
      243,  245,  248,  250,  252,  254,  256,  258,  260,  262,
      265,  267,  269,  271,  273,  275,  277,  279,  281,  283,
      285,  287,  289,  290,  291,  291,  291,  291,  291,  291,
      291,  291,  292,  292,  293,  293,  293,  294,  296,  298,
      298,  299,  300,  301,  302,  303,  304,  305,  307,  309,
      309,  310,  310,  310,  311,  311,  313,  315,  317,  319,
      321,  323,  325,  327,  329,  331,  333,  335,  337,  339,
      341,  344,  346,  348,  350,  352,  354,  356,  358,  360,

      362,  364,  366,  368,  370,  373,  375,  377,  380,  382,
      384,  386,  388,  390,  392,  394,  396,  398,  400,  402,
      404,  406,  408,  410,  412,  414,  414,  414,  414,  414,
      414,  414,  414,  414,  414,  414,  414,  415,  415,  417,
      419,  421,  422,  423,  424,  425,  427,  429,  431,  434,
      436,  438,  440,  442,  444,  446,  448,  450,  452,  454,
      456,  458,  460,  462,  464,  466,  468,  471,  474,  476,
      479,  482,  484,  486,  488,  490,  493,  496,  498,  500,
      502,  505,  507,  510,  512,  514,  516,  518,  520,  522,
      524,  526,  528,  531,  533,  535,  537,  540,  542,  544,

      544,  545,  545,  545,  545,  545,  545,  546,  546,  546,
      546,  546,  546,  548,  549,  550,  551,  554,  556,  558,
      561,  563,  566,  568,  570,  572,  574,  576,  578,  580,
      582,  584,  586,  588,  590,  592,  594,  597,  600,  603,
      605,  607,  609,  611,  614,  617,  619,  621,  623,  625,
      628,  630,  632,  634,  636,  638,  640,  643,  645,  647,
      650,  650,  650,  650,  651,  651,  651,  651,  651,  651,
      651,  651,  652,  654,  656,  658,  658,  660,  662,  664,
      666,  668,  670,  672,  674,  676,  678,  680,  682,  684,
      686,  688,  690,  692,  694,  697,  700,  703,  705,  707,

      710,  713,  716,  719,  722,  725,  727,  729,  731,  731,
      731,  732,  732,  733,  733,  733,  733,  733,  733,  734,
      736,  738,  740,  740,  743,  745,  748,  751,  753,  755,
      757,  759,  762,  764,  766,  768,  770,  772,  774,  776,
      778,  781,  783,  785,  788,  790,  792,  792,  792,  792,
      792,  793,  793,  793,  793,  793,  793,  795,  797,  799,
      799,  799,  801,  803,  805,  808,  811,  813,  815,  818,
      820,  823,  825,  827,  830,  833,  836,  836,  839,  842,
      843,  843,  843,  843,  843,  843,  844,  844,  844,  845,
      845,  846,  848,  850,  853,  853,  853,  853,  855,  857,

      859,  861,  863,  866,  868,  870,  873,  876,  878,  878,
      879,  880,  880,  880,  880,  880,  882,  884,  884,  884,
      884,  886,  888,  890,  893,  896,  899,  902,  904,  907,
      907,  907,  907,  907,  907,  909,  911,  911,  911,  911,
      914,  914,  914,  916,  918,  921,  923,  923,  923,  923,
      923,  923,  925,  927,  927,  927,  927,  929,  929,  929,
      929,  931,  934,  937,  937,  937,  937,  937,  937,  939,
      941,  941,  941,  941,  944,  945,  945,  948,  948,  948,
      948,  948,  948,  950,  952,  953,  953,  953,  953,  953,
      953,  953,  953,  953,  955,  957,  957,  957,  957,  957,

      957,  957,  957,  957,  959,  961,  961,  962,  962,  962,
      962,  962,  962,  962,  965,  967,  967,  967,  967,  967,
      967,  967,  967,  970,  970,  970,  970,  970,  970,  970,
      970,  970,  970,  970,  970,  970,  970,  970,  971,  971,
      971,  971,  971,  971,  971,  971,  971,  971,  971,  972,
      972,  972,  974,  974,  974,  974,  974,  974,  974,  975,
      975,  975,  977,  977,  977,  977,  978,  978,  978,  978,
      978,  978,  978,  978,  978,  979,  979
    } ;

static yyconst YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    1,    9,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
       23,   24,   23,   25,   23,   26,   27,   28,   29,   30,
       31,   32,   33,    1,   34,   35,   36,   37,   38,   39,
       40,   41,   42,   41,   41,   43,   41,   44,   45,   41,
       41,   46,   47,   48,   49,   41,   41,   50,   41,   41,
       51,   52,   53,   54,   55,    1,   56,   57,   58,   59,

       60,   61,   62,   63,   64,   65,   66,   67,   68,   69,
       70,   71,   65,   72,   73,   74,   75,   76,   77,   78,
       79,   80,   81,   82,   83,   84,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst YY_CHAR yy_meta[85] =
    {   0,
        1,    2,    3,    1,    2,    1,    1,    1,    1,    1,
        1,    4,    1,    1,    1,    5,    1,    1,    1,    6,
        6,    6,    6,    6,    6,    6,    6,    1,    1,    1,
        5,    1,    1,    7,    7,    7,    7,    7,    7,    8,
        8,    8,    8,    8,    8,    8,    8,    8,    8,    8,
        1,    1,    1,    1,    8,    9,    9,    9,    9,    9,
        9,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
        1,    1,    1,    1
    } ;

static yyconst flex_uint16_t yy_base[704] =
    {   0,
        0,    0, 1173, 1174,   83,    0, 1141,   79,   84,   59,
       82,   82, 1174, 1174, 1140,   79, 1174,   80,   78,   95,
      138,  199, 1138, 1174,   97, 1138,   76, 1174,    0, 1134,
     1112,  108, 1120, 1174, 1162, 1174, 1133,   85,   43,   51,
       76,   75,   55,   80, 1093,   69, 1092, 1101,  103,   70,
     1091, 1089, 1095, 1174,   86, 1174, 1174,  167,    0, 1174,
      130, 1174, 1154,  169, 1096,   85, 1094, 1090, 1081, 1174,
     1174, 1174, 1174,  159, 1174, 1149, 1174, 1174, 1174, 1174,
     1174, 1174, 1133,  255,  173,    0, 1174,    0,  165,    0,
      229,  161,  130,    0, 1174, 1174, 1174, 1119, 1174, 1174,

     1174, 1118,    0, 1105, 1107,  134,  189, 1097, 1174, 1174,
     1075, 1074,  227, 1075, 1068, 1071, 1080, 1066, 1082, 1068,
     1075, 1060, 1061, 1058, 1058, 1064, 1060, 1057, 1054,    0,
      132, 1058,  156, 1056,  121,  175, 1061, 1049, 1052,  194,
      145, 1058, 1174, 1174,  285, 1060,  196, 1061,  202, 1050,
     1062, 1174,  303, 1174, 1087,    0,    0,  190,  195,  311,
      319,  104, 1174,  221,  246, 1174, 1174, 1069,  185,  150,
     1174, 1112,  262, 1174, 1111, 1075, 1042, 1039,  111,  289,
     1050, 1031, 1039, 1037, 1046,  171, 1026, 1040, 1033, 1077,
        0, 1031, 1033, 1043, 1038, 1025,  276, 1040, 1038, 1034,

     1025, 1032, 1018, 1034,    0, 1019, 1024,    0, 1025, 1022,
     1011, 1009, 1011, 1013, 1021, 1006, 1004, 1004, 1017, 1016,
     1005, 1010, 1014, 1016, 1004, 1067, 1005, 1007, 1007, 1002,
     1062, 1004, 1004, 1002,  999,  343,  351, 1028,  304, 1174,
      225, 1174, 1174,  338,  317, 1021, 1014, 1015,    0,  989,
      995,  986,  979,  992,  982,  992,  975,  196,  979,  974,
      984,  986,  973,  974,  975, 1017,    0,    0,  974,    0,
        0,  965,  974,  962,  969,    0,    0,  963,  974,  959,
        0,  963,    0,  958,  958,  957,  954,  967,  956,  961,
      966,  965,    0,  963,  952,  958,    0,  945,  958, 1014,

     1174,  947, 1010, 1011,  952, 1009, 1174,  950,  950, 1004,
      940,  383, 1174,  307, 1174,  340,    0,  959,  962,    0,
      931,  387,  932,  945,  929,  934,  940,  935,  326,  929,
      923,  927,  937,  934,  919,  936,    0,    0,    0,  922,
      923,  929,  919,    0,    0,  927,  912,  921,  915,    0,
      924,  921,  923,  906,  916,  918,    0,  908,  912,    0,
      915,  971,  970, 1174,  969,  350,  910,  399,  914,  955,
      949, 1174,  942,  918,  890,  391,  909,  899,  895,  887,
      887,  890,  889,  935,  932,  880,  882,  893,  896,  881,
      929,  875,  873,  873,    0,    0,    0,  886,  887,    0,

        0,    0,    0,    0,    0,  883,  883,  875,  936,  937,
     1174,  936, 1174,  396,  397,  352,  409,  933, 1174,  913,
      911,  863,  864,  404,  876,    0,    0,  861,  858,  870,
      903,    0,  861,  863,  867,  858,  863,  901,  858,  861,
        0,  848,  845,  913,  858,  856,    0,  860,  911,  435,
     1174,  400,  439,  443,  910,  909,  856,  886,  840,  841,
      445,  832,  846,  841,  849,  848,  835,  843,  845,  832,
        0,  872,  830,    0,    0,    0,  838,    0,    0,  883,
      854,  413,  838,  889,  454, 1174,  407,  888, 1174,  887,
     1174,  853,  833,    0,  831,  831,  815,  810,  825,  812,

      826,  806,    0,  805,  823,    0,  822,  816,  812, 1174,
      862,  831,  401,  832,  414,  826,  834,  795,  792,  800,
      806,  456,  796,    0,    0,  809,    0,  789,  807,  805,
      805,  408,  817,  424,  814,  812,  792,  785,  798,  798,
      467,  793,  796,  795,    0,  794,  776,  800,  314,  791,
      425,  798,  800,  776,  775,  767,  785,    0,  826,  259,
      783,    0,    0,  832,  800,  457,  788,  436,  786,  786,
      772,  775,  766,    0, 1174,  402,    0,  774,  794,  461,
      791,  467,  792,  777, 1174,  750,  756,  452,  767,  777,
      468,  786,  471,  775,  784,  753,  756,  462,  742,  770,

      473,  769,  474,  764,  767,  743, 1174,  465,  735,  770,
      478,  763,  481,    0,  758,  745,  472,  748,  757,  483,
      764,  488,    0,  746,  469,  726,  744,  484,  752,  485,
      725,  476,  671,  679,  489,  678,  493, 1174,  486,  674,
      499,  505,  676,  494,  501,  675,  720,  618, 1174,  617,
      594, 1174,  530,  535,  574,  496,  544,  543, 1174,  539,
      538, 1174,  521,  517,  454,  507,  446,  455,  439,  432,
      242,  210,  171,   92, 1174, 1174,  549,  559,  569,  574,
      584,  589,  598,  608,  617,  627,  637,  647,  657,  667,
      677,  681,  691,  701,  711,  718,  727,  737,  747,  757,

      767,  777,  787
    } ;

static yyconst flex_int16_t yy_def[704] =
    {   0,
      676,    1,  676,  676,  676,  677,  676,  678,  676,  676,
      676,  679,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  680,  680,
      680,  680,  680,  676,  676,  676,  676,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
      680,  680,  680,  676,  676,  676,  676,  676,  677,  676,
      678,  676,  678,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  679,  676,  679,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  681,  676,   84,   21,   22,
      676,  676,  676,  682,  676,  676,  676,  676,  676,  676,

      676,  676,  680,  680,  680,  683,  684,  680,  676,  676,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
      680,  680,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  685,  681,  676,  676,  676,
      676,  676,  676,  676,  682,  676,  676,  680,  680,  683,
      676,  683,  684,  676,  684,  680,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,

      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  686,  676,  676,  676,  676,
      687,  676,  676,  676,  676,  676,  676,  685,  676,  676,
      676,  676,  676,  676,  676,  680,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  686,

      676,  676,  676,  688,  676,  687,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
      676,  689,  688,  676,  690,  676,  676,  676,  676,  676,
      676,  676,  680,  680,  680,  676,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,

      680,  680,  680,  680,  680,  680,  680,  680,  676,  689,
      676,  690,  676,  676,  691,  676,  676,  676,  676,  680,
      680,  680,  676,  680,  680,  680,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  692,  676,  691,  691,
      676,  691,  676,  693,  694,  695,  680,  680,  680,  676,
      676,  680,  680,  680,  680,  680,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  676,  680,  680,  696,
      676,  691,  676,  693,  693,  676,  693,  694,  676,  695,
      676,  680,  680,  680,  676,  676,  676,  680,  680,  680,

      680,  680,  680,  680,  680,  680,  680,  680,  676,  676,
      696,  676,  691,  676,  693,  680,  680,  676,  676,  676,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  676,
      676,  691,  676,  693,  680,  680,  676,  676,  676,  680,
      676,  697,  680,  680,  680,  680,  676,  676,  691,  676,
      693,  680,  680,  676,  676,  676,  680,  697,  697,  697,
      680,  680,  680,  676,  676,  691,  676,  693,  680,  680,
      676,  676,  676,  680,  676,  697,  680,  676,  676,  691,
      676,  693,  680,  680,  676,  676,  676,  697,  676,  676,
      691,  676,  693,  680,  680,  676,  676,  697,  676,  676,

      691,  676,  693,  680,  680,  676,  676,  697,  676,  676,
      691,  676,  693,  680,  680,  676,  697,  676,  676,  691,
      676,  693,  680,  676,  697,  676,  676,  691,  676,  693,
      676,  697,  676,  676,  691,  676,  693,  676,  697,  676,
      698,  699,  676,  693,  697,  676,  698,  698,  676,  699,
      699,  676,  700,  701,  702,  676,  700,  700,  676,  701,
      701,  676,  702,  702,  676,  702,  676,  676,  676,  676,
      676,  676,  703,  703,  676,    0,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,

      676,  676,  676
    } ;

static yyconst flex_uint16_t yy_nxt[1259] =
    {   0,
        4,    5,    6,    5,    5,    7,    8,    9,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
       22,   22,   22,   22,   22,   22,   22,   23,   24,   25,
       26,   27,   28,   29,   29,   29,   29,   29,   30,   31,
       29,   29,   32,   29,   29,   29,   29,   33,   29,   29,
       34,   35,   36,   37,   38,   39,   40,   41,   42,   43,
       44,   45,   29,   46,   29,   29,   47,   29,   29,   29,
       29,   48,   49,   50,   51,   52,   53,   29,   29,   29,
       54,   55,   56,   57,   58,   62,   58,   58,   64,   70,
       71,   72,   75,   78,  675,   83,   80,   84,   84,   84,

       84,   84,   84,   84,   84,   96,  101,  102,   85,   79,
       81,   82,   73,   86,  106,  114,  143,  115,  107,  111,
      116,  123,  117,  124,   97,   87,   98,   99,  112,  130,
       63,  118,  125,   76,  121,  126,   62,  131,  119,  113,
      171,  138,   65,   66,  122,  120,  127,   67,  139,  128,
       68,  147,  163,  148,   69,   88,  171,   89,   89,   89,
       89,   89,   89,   90,   90,  134,  135,  144,   58,   75,
       58,   58,  164,  675,  155,   91,  136,  155,  163,  137,
       92,   63,  214,  252,  253,  172,   93,   94,  145,  145,
      145,  145,  145,  145,  145,  145,  164,   91,  207,  174,

      215,  172,  156,  162,   92,  208,  231,  158,  223,  163,
       76,  224,   93,  159,  676,   94,   88,  210,   90,   90,
       90,   90,   90,   90,   90,   90,  247,  162,  211,  212,
      216,  158,  239,  248,  261,  163,   91,  241,  240,  159,
      175,   92,  676,  160,  262,  160,  217,   93,  161,  161,
      161,  161,  161,  161,  161,  161,  239,  221,   91,  228,
      232,  241,  328,  243,  240,   92,  222,  313,  229,  329,
      233,  575,  174,   93,   84,   84,   84,   84,   84,   84,
       84,   84,  179,  673,  180,  181,  182,  243,  244,  226,
      183,  313,  153,  154,  245,  184,  672,  154,  185,  186,

      187,  188,  189,  190,  145,  145,  145,  145,  145,  145,
      145,  145,  244,  175,  153,  154,  451,  236,  576,  236,
      245,  154,  237,  237,  237,  237,  237,  237,  237,  237,
      161,  161,  161,  161,  161,  161,  161,  161,  161,  161,
      161,  161,  161,  161,  161,  161,  384,  254,  272,  273,
      385,  414,  240,  453,  415,  315,  454,  242,  255,  316,
      566,  242,  237,  237,  237,  237,  237,  237,  237,  237,
      237,  237,  237,  237,  237,  237,  237,  237,  240,  242,
      314,  315,  372,  316,  370,  242,  315,  370,  376,  154,
      376,  376,  376,  154,  376,  376,  371,  414,  450,  451,

      414,  450,  451,  451,  314,  461,  372,  461,  461,  486,
      451,  154,  315,  455,  575,  451,  486,  154,  417,  417,
      417,  417,  417,  417,  417,  417,  486,  486,  417,  417,
      417,  417,  417,  417,  417,  417,  450,  451,  486,  450,
      453,  377,  532,  453,  485,  486,  461,  485,  461,  461,
      448,  452,  513,  534,  482,  485,  486,  541,  485,  451,
      541,  515,  549,  451,  575,  551,  423,  542,  541,  486,
      451,  541,  588,  486,  575,  451,  486,  575,  558,  568,
      451,  575,  582,  486,  575,  451,  451,  486,  575,  452,
      486,  451,  580,  483,  591,  486,  486,  487,  575,  496,

      648,  649,  593,  648,  603,  671,  651,  652,  487,  651,
      670,  601,  655,  575,  669,  620,  611,  613,  668,  666,
      497,  608,  617,  598,  622,  630,  667,  625,  628,  666,
      637,  658,  659,  664,  658,  639,  661,  662,  635,  661,
      662,  662,  632,  642,  645,  659,  659,  644,  654,   59,
       59,  665,   59,   59,   59,   59,   59,   59,   59,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   74,
       74,   74,   74,   74,   74,   74,   74,   74,   74,  103,
      103,  103,  103,  103,  157,  157,  664,  157,  157,  157,
      157,  157,  157,  157,  165,  165,  652,  165,  170,  170,

      170,  170,  170,  170,  170,  170,  170,  170,  173,  173,
      173,  173,  173,  173,  173,  173,  173,  173,  238,  652,
      649,  238,  238,  238,  238,  238,  238,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  306,  306,  306,
      306,  306,  306,  306,  306,  306,  306,  363,  363,  363,
      363,  363,  363,  363,  363,  363,  363,  410,  410,  410,
      410,  410,  410,  410,  410,  410,  410,  412,  412,  412,
      412,  412,  412,  412,  412,  412,  412,  449,  449,  449,
      449,  449,  449,  449,  449,  449,  449,  480,  480,  480,
      480,  484,  484,  484,  484,  484,  484,  484,  484,  484,

      484,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  490,  490,  490,  490,  490,  490,  490,  490,  490,
      490,  511,  649,  511,  511,  511,  511,  511,  559,  656,
      653,  646,  643,  641,  640,  559,  559,  647,  647,  647,
      647,  647,  647,  647,  647,  647,  647,  650,  650,  650,
      650,  650,  650,  650,  650,  650,  650,  657,  657,  657,
      657,  657,  657,  657,  657,  657,  657,  660,  660,  660,
      660,  660,  660,  660,  660,  660,  660,  663,  663,  638,
      663,  663,  663,  663,  663,  663,  663,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  636,  634,  633,

      631,  629,  627,  626,  624,  623,  621,  619,  618,  616,
      615,  614,  612,  610,  609,  607,  606,  605,  604,  602,
      600,  599,  597,  596,  595,  594,  592,  590,  589,  587,
      586,  585,  584,  583,  581,  579,  578,  577,  575,  574,
      573,  572,  571,  570,  569,  567,  565,  564,  563,  562,
      561,  560,  557,  556,  555,  554,  553,  552,  550,  548,
      547,  546,  545,  544,  543,  540,  539,  538,  537,  536,
      535,  533,  531,  510,  530,  529,  528,  527,  526,  525,
      524,  523,  522,  521,  520,  519,  518,  517,  516,  491,
      489,  486,  514,  512,  510,  509,  508,  507,  506,  505,

      504,  503,  502,  501,  500,  499,  498,  495,  494,  493,
      492,  491,  489,  451,  481,  479,  478,  477,  476,  475,
      474,  473,  472,  471,  470,  469,  468,  467,  466,  465,
      464,  463,  462,  460,  459,  458,  457,  456,  413,  411,
      447,  446,  445,  444,  443,  442,  441,  440,  439,  438,
      437,  436,  435,  434,  433,  432,  431,  430,  429,  428,
      427,  426,  425,  424,  422,  421,  420,  419,  371,  418,
      416,  413,  364,  411,  409,  408,  407,  406,  405,  404,
      403,  402,  401,  400,  399,  398,  397,  396,  395,  394,
      393,  392,  391,  390,  389,  388,  387,  386,  383,  382,

      381,  380,  379,  378,  375,  374,  373,  369,  368,  367,
      366,  307,  365,  364,  362,  361,  301,  360,  359,  358,
      357,  356,  355,  354,  353,  352,  351,  350,  349,  348,
      347,  346,  345,  344,  343,  342,  341,  340,  339,  338,
      337,  336,  335,  334,  333,  332,  331,  330,  327,  326,
      325,  324,  323,  322,  321,  320,  319,  318,  317,  312,
      311,  310,  309,  308,  307,  305,  304,  303,  302,  301,
      299,  298,  297,  296,  295,  294,  293,  292,  291,  290,
      289,  288,  287,  286,  285,  284,  283,  282,  281,  280,
      279,  278,  277,  276,  275,  274,  271,  270,  269,  268,

      267,  266,  265,  264,  263,  260,  259,  258,  257,  256,
      251,  250,  249,  676,  676,  246,  156,  235,  234,  230,
      227,  225,  220,  219,  218,  213,  209,  206,  205,  204,
      203,  202,  201,  200,  199,  198,  197,  196,  195,  194,
      193,  192,  191,  178,  177,  176,  169,  168,  167,  166,
      152,  676,  151,  150,  149,  146,  676,  142,  141,  140,
      133,  132,  129,  110,  109,  108,  105,  104,  100,   95,
       77,   60,  676,    3,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,

      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676
    } ;

static yyconst flex_int16_t yy_chk[1259] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    5,    8,    5,    5,    9,   10,
       10,   11,   12,   16,  674,   19,   18,   19,   19,   19,

       19,   19,   19,   19,   19,   25,   27,   27,   20,   16,
       18,   18,   11,   20,   32,   39,   55,   39,   32,   38,
       40,   43,   40,   43,   25,   20,   25,   25,   38,   46,
        8,   41,   43,   12,   42,   44,   61,   46,   41,   38,
      106,   50,    9,    9,   42,   41,   44,    9,   50,   44,
        9,   66,  162,   66,    9,   21,  170,   21,   21,   21,
       21,   21,   21,   21,   21,   49,   49,   55,   58,   74,
       58,   58,   93,  673,   85,   21,   49,   85,  162,   49,
       21,   61,  135,  179,  179,  106,   21,   21,   64,   64,
       64,   64,   64,   64,   64,   64,   93,   21,  131,  107,

      135,  170,   85,   92,   21,  131,  149,   89,  141,   92,
       74,  141,   21,   89,   89,   21,   22,  133,   22,   22,
       22,   22,   22,   22,   22,   22,  169,   92,  133,  133,
      136,   89,  158,  169,  186,   92,   22,  159,  158,   89,
      107,   22,   89,   91,  186,   91,  136,   22,   91,   91,
       91,   91,   91,   91,   91,   91,  158,  140,   22,  147,
      149,  159,  258,  164,  158,   22,  140,  241,  147,  258,
      149,  560,  173,   22,   84,   84,   84,   84,   84,   84,
       84,   84,  113,  672,  113,  113,  113,  164,  165,  145,
      113,  241,   84,   84,  165,  113,  671,   84,  113,  113,

      113,  113,  113,  113,  145,  145,  145,  145,  145,  145,
      145,  145,  165,  173,   84,   84,  549,  153,  560,  153,
      165,   84,  153,  153,  153,  153,  153,  153,  153,  153,
      160,  160,  160,  160,  160,  160,  160,  160,  161,  161,
      161,  161,  161,  161,  161,  161,  329,  180,  197,  197,
      329,  366,  239,  416,  366,  314,  416,  161,  180,  245,
      549,  161,  236,  236,  236,  236,  236,  236,  236,  236,
      237,  237,  237,  237,  237,  237,  237,  237,  239,  161,
      244,  314,  316,  245,  312,  161,  244,  312,  322,  237,
      322,  322,  376,  237,  376,  376,  312,  414,  415,  415,

      414,  415,  452,  513,  244,  424,  316,  424,  424,  487,
      532,  237,  244,  417,  576,  482,  515,  237,  368,  368,
      368,  368,  368,  368,  368,  368,  534,  551,  417,  417,
      417,  417,  417,  417,  417,  417,  450,  450,  568,  450,
      453,  322,  513,  453,  454,  454,  461,  454,  461,  461,
      414,  415,  482,  515,  452,  485,  485,  522,  485,  566,
      522,  487,  532,  580,  588,  534,  376,  522,  541,  582,
      591,  541,  576,  593,  598,  601,  603,  608,  541,  551,
      611,  625,  568,  613,  617,  620,  628,  630,  632,  450,
      622,  635,  566,  453,  580,  637,  644,  454,  639,  461,

      641,  641,  582,  641,  593,  670,  642,  642,  485,  642,
      669,  591,  645,  645,  668,  611,  601,  603,  667,  666,
      461,  598,  608,  588,  613,  622,  665,  617,  620,  664,
      630,  653,  653,  663,  653,  632,  654,  654,  628,  654,
      661,  660,  625,  635,  639,  658,  657,  637,  644,  677,
      677,  656,  677,  677,  677,  677,  677,  677,  677,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  679,
      679,  679,  679,  679,  679,  679,  679,  679,  679,  680,
      680,  680,  680,  680,  681,  681,  655,  681,  681,  681,
      681,  681,  681,  681,  682,  682,  651,  682,  683,  683,

      683,  683,  683,  683,  683,  683,  683,  683,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  685,  650,
      648,  685,  685,  685,  685,  685,  685,  686,  686,  686,
      686,  686,  686,  686,  686,  686,  686,  687,  687,  687,
      687,  687,  687,  687,  687,  687,  687,  688,  688,  688,
      688,  688,  688,  688,  688,  688,  688,  689,  689,  689,
      689,  689,  689,  689,  689,  689,  689,  690,  690,  690,
      690,  690,  690,  690,  690,  690,  690,  691,  691,  691,
      691,  691,  691,  691,  691,  691,  691,  692,  692,  692,
      692,  693,  693,  693,  693,  693,  693,  693,  693,  693,

      693,  694,  694,  694,  694,  694,  694,  694,  694,  694,
      694,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  696,  647,  696,  696,  696,  696,  696,  697,  646,
      643,  640,  636,  634,  633,  697,  697,  698,  698,  698,
      698,  698,  698,  698,  698,  698,  698,  699,  699,  699,
      699,  699,  699,  699,  699,  699,  699,  700,  700,  700,
      700,  700,  700,  700,  700,  700,  700,  701,  701,  701,
      701,  701,  701,  701,  701,  701,  701,  702,  702,  631,
      702,  702,  702,  702,  702,  702,  702,  703,  703,  703,
      703,  703,  703,  703,  703,  703,  703,  629,  627,  626,

      624,  621,  619,  618,  616,  615,  612,  610,  609,  606,
      605,  604,  602,  600,  599,  597,  596,  595,  594,  592,
      590,  589,  587,  586,  584,  583,  581,  579,  578,  573,
      572,  571,  570,  569,  567,  565,  564,  561,  559,  557,
      556,  555,  554,  553,  552,  550,  548,  547,  546,  544,
      543,  542,  540,  539,  538,  537,  536,  535,  533,  531,
      530,  529,  528,  526,  523,  521,  520,  519,  518,  517,
      516,  514,  512,  511,  509,  508,  507,  505,  504,  502,
      501,  500,  499,  498,  497,  496,  495,  493,  492,  490,
      488,  484,  483,  481,  480,  477,  473,  472,  470,  469,

      468,  467,  466,  465,  464,  463,  462,  460,  459,  458,
      457,  456,  455,  449,  448,  446,  445,  444,  443,  442,
      440,  439,  438,  437,  436,  435,  434,  433,  431,  430,
      429,  428,  425,  423,  422,  421,  420,  418,  412,  410,
      409,  408,  407,  406,  399,  398,  394,  393,  392,  391,
      390,  389,  388,  387,  386,  385,  384,  383,  382,  381,
      380,  379,  378,  377,  375,  374,  373,  371,  370,  369,
      367,  365,  363,  362,  361,  359,  358,  356,  355,  354,
      353,  352,  351,  349,  348,  347,  346,  343,  342,  341,
      340,  336,  335,  334,  333,  332,  331,  330,  328,  327,

      326,  325,  324,  323,  321,  319,  318,  311,  310,  309,
      308,  306,  305,  304,  303,  302,  300,  299,  298,  296,
      295,  294,  292,  291,  290,  289,  288,  287,  286,  285,
      284,  282,  280,  279,  278,  275,  274,  273,  272,  269,
      266,  265,  264,  263,  262,  261,  260,  259,  257,  256,
      255,  254,  253,  252,  251,  250,  248,  247,  246,  238,
      235,  234,  233,  232,  231,  230,  229,  228,  227,  226,
      225,  224,  223,  222,  221,  220,  219,  218,  217,  216,
      215,  214,  213,  212,  211,  210,  209,  207,  206,  204,
      203,  202,  201,  200,  199,  198,  196,  195,  194,  193,

      192,  190,  189,  188,  187,  185,  184,  183,  182,  181,
      178,  177,  176,  175,  172,  168,  155,  151,  150,  148,
      146,  142,  139,  138,  137,  134,  132,  129,  128,  127,
      126,  125,  124,  123,  122,  121,  120,  119,  118,  117,
      116,  115,  114,  112,  111,  108,  105,  104,  102,   98,
       83,   76,   69,   68,   67,   65,   63,   53,   52,   51,
       48,   47,   45,   37,   35,   33,   31,   30,   26,   23,
       15,    7,    3,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,

      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676
    } ;

extern int yy_flex_debug;
int yy_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "giscanner/scannerlexer.l"
/* -*- Mode: C -*-
 * GObject introspection: C lexer
 *
 * Copyright (c) 1997 Sandro Sigala  <ssigala@globalnet.it>
 * Copyright (c) 2007-2008 Jürg Billeter  <j@bitron.ch>
 * Copyright (c) 2010 Andreas Rottmann <a.rottmann@gmx.at>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#line 32 "giscanner/scannerlexer.l"
#include <ctype.h>
#include <stdio.h>
#include <string.h>
#ifndef _WIN32
#include <limits.h>
#endif

#include <glib.h>
#include "sourcescanner.h"
#include "scannerparser.h"

#ifdef USE_WINDOWS
#include <windows.h>
#endif

int lineno;
char linebuf[2000];

#undef YY_BUF_SIZE
#define YY_BUF_SIZE 1048576

extern int yylex (GISourceScanner *scanner);
#define YY_DECL int yylex (GISourceScanner *scanner)
static int yywrap (void);
static void parse_comment (GISourceScanner *scanner);
static void parse_trigraph (GISourceScanner *scanner);
static void process_linemarks (GISourceScanner *scanner, gboolean has_line);
static int check_identifier (GISourceScanner *scanner, const char *);
static int parse_ignored_macro (void);
static void print_error (GISourceScanner *scanner);
#line 1149 "scannerlexer.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * _in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * _out_str  );

yy_size_t yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	{
#line 73 "giscanner/scannerlexer.l"


#line 1374 "scannerlexer.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 677 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1174 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
					{
					(yy_full_match) = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 75 "giscanner/scannerlexer.l"
{ strncpy(linebuf, yytext+1, sizeof(linebuf)); /* save the next line */
						linebuf[sizeof(linebuf)-1]='\0';
						/* printf("%4d:%s\n",lineno,linebuf); */
						yyless(1);      /* give back all but the \n to rescan */
						++lineno;
					}
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 81 "giscanner/scannerlexer.l"
{ ++lineno; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 83 "giscanner/scannerlexer.l"
{ /* Ignore whitespace. */ }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 85 "giscanner/scannerlexer.l"
{ parse_comment(scanner); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 86 "giscanner/scannerlexer.l"
{ parse_trigraph(scanner); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 87 "giscanner/scannerlexer.l"
{ /* Ignore C++ style comments. */ }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 89 "giscanner/scannerlexer.l"
{ yyless (yyleng - 1); return FUNCTION_MACRO; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 90 "giscanner/scannerlexer.l"
{ return OBJECT_MACRO; }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 91 "giscanner/scannerlexer.l"
{ ++lineno; return IFDEF_GI_SCANNER; }
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 92 "giscanner/scannerlexer.l"
{ ++lineno; return IFNDEF_GI_SCANNER; }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 93 "giscanner/scannerlexer.l"
{ ++lineno; return IFNDEF_COND; }
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 94 "giscanner/scannerlexer.l"
{ ++lineno; return IFDEF_COND; }
	YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 95 "giscanner/scannerlexer.l"
{ ++lineno; return IF_COND; }
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 96 "giscanner/scannerlexer.l"
{ ++lineno; return ELIF_COND; }
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 97 "giscanner/scannerlexer.l"
{ ++lineno; return ELSE_COND; }
	YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 98 "giscanner/scannerlexer.l"
{ ++lineno; return ENDIF_COND; }
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 99 "giscanner/scannerlexer.l"
{ ++lineno; /* Ignore pragma. */ }
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 101 "giscanner/scannerlexer.l"
{ ++lineno; process_linemarks(scanner, FALSE); }
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 102 "giscanner/scannerlexer.l"
{ ++lineno; process_linemarks(scanner, TRUE); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 103 "giscanner/scannerlexer.l"
{ }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 104 "giscanner/scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 105 "giscanner/scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 106 "giscanner/scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 107 "giscanner/scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 108 "giscanner/scannerlexer.l"
{ return '['; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 109 "giscanner/scannerlexer.l"
{ return '['; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 110 "giscanner/scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 111 "giscanner/scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 112 "giscanner/scannerlexer.l"
{ return '('; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 113 "giscanner/scannerlexer.l"
{ return ')'; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 114 "giscanner/scannerlexer.l"
{ return ';'; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 115 "giscanner/scannerlexer.l"
{ return ':'; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 116 "giscanner/scannerlexer.l"
{ return ELLIPSIS; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 117 "giscanner/scannerlexer.l"
{ return '?'; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 118 "giscanner/scannerlexer.l"
{ return '.'; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 119 "giscanner/scannerlexer.l"
{ return '+'; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 120 "giscanner/scannerlexer.l"
{ return '-'; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 121 "giscanner/scannerlexer.l"
{ return '*'; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 122 "giscanner/scannerlexer.l"
{ return '/'; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 123 "giscanner/scannerlexer.l"
{ return '%'; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 124 "giscanner/scannerlexer.l"
{ return '^'; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 125 "giscanner/scannerlexer.l"
{ return '&'; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 126 "giscanner/scannerlexer.l"
{ return '|'; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 127 "giscanner/scannerlexer.l"
{ return '~'; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 128 "giscanner/scannerlexer.l"
{ return '!'; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 129 "giscanner/scannerlexer.l"
{ return '='; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 130 "giscanner/scannerlexer.l"
{ return '<'; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 131 "giscanner/scannerlexer.l"
{ return '>'; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 132 "giscanner/scannerlexer.l"
{ return ADDEQ; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 133 "giscanner/scannerlexer.l"
{ return SUBEQ; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 134 "giscanner/scannerlexer.l"
{ return MULEQ; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 135 "giscanner/scannerlexer.l"
{ return DIVEQ; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 136 "giscanner/scannerlexer.l"
{ return MODEQ; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 137 "giscanner/scannerlexer.l"
{ return XOREQ; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 138 "giscanner/scannerlexer.l"
{ return ANDEQ; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 139 "giscanner/scannerlexer.l"
{ return OREQ; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 140 "giscanner/scannerlexer.l"
{ return SL; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 141 "giscanner/scannerlexer.l"
{ return SR; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 142 "giscanner/scannerlexer.l"
{ return SLEQ; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 143 "giscanner/scannerlexer.l"
{ return SREQ; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 144 "giscanner/scannerlexer.l"
{ return EQ; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 145 "giscanner/scannerlexer.l"
{ return NOTEQ; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 146 "giscanner/scannerlexer.l"
{ return LTEQ; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 147 "giscanner/scannerlexer.l"
{ return GTEQ; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 148 "giscanner/scannerlexer.l"
{ return ANDAND; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 149 "giscanner/scannerlexer.l"
{ return OROR; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 150 "giscanner/scannerlexer.l"
{ return PLUSPLUS; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 151 "giscanner/scannerlexer.l"
{ return MINUSMINUS; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 152 "giscanner/scannerlexer.l"
{ return ','; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 153 "giscanner/scannerlexer.l"
{ return ARROW; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 155 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 156 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 157 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 158 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 159 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 160 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 161 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 162 "giscanner/scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 163 "giscanner/scannerlexer.l"
{ return EXTENSION; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 164 "giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 165 "giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 166 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 167 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 168 "giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 169 "giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 170 "giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 171 "giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 172 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 173 "giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 174 "giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 175 "giscanner/scannerlexer.l"
{ return BOOL; }
	YY_BREAK
case 92:
/* rule 92 can match eol */
YY_RULE_SETUP
#line 176 "giscanner/scannerlexer.l"
{ ++lineno; /* Ignore */ }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 177 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 178 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 179 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 180 "giscanner/scannerlexer.l"
{ /* ignore */ }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 181 "giscanner/scannerlexer.l"
{ /* ignore */ }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 182 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 185 "giscanner/scannerlexer.l"
{ return INTL_CONST; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 186 "giscanner/scannerlexer.l"
{ return INTUL_CONST; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 188 "giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 189 "giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 190 "giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 191 "giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 193 "giscanner/scannerlexer.l"
{ if (scanner->macro_scan) return check_identifier(scanner, yytext); else REJECT; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 195 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 196 "giscanner/scannerlexer.l"
{ return AUTO; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 197 "giscanner/scannerlexer.l"
{ return BOOL; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 198 "giscanner/scannerlexer.l"
{ return BREAK; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 199 "giscanner/scannerlexer.l"
{ return CASE; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 200 "giscanner/scannerlexer.l"
{ return CHAR; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 201 "giscanner/scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 202 "giscanner/scannerlexer.l"
{ return CONTINUE; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 203 "giscanner/scannerlexer.l"
{ return DEFAULT; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 204 "giscanner/scannerlexer.l"
{ return DO; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 205 "giscanner/scannerlexer.l"
{ return DOUBLE; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 206 "giscanner/scannerlexer.l"
{ return ELSE; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 207 "giscanner/scannerlexer.l"
{ return ENUM; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 208 "giscanner/scannerlexer.l"
{ return EXTERN; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 209 "giscanner/scannerlexer.l"
{ return FLOAT; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 210 "giscanner/scannerlexer.l"
{ return FOR; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 211 "giscanner/scannerlexer.l"
{ return GOTO; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 212 "giscanner/scannerlexer.l"
{ return IF; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 213 "giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 214 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 215 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 216 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 217 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 218 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 219 "giscanner/scannerlexer.l"
{ return LONG; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 220 "giscanner/scannerlexer.l"
{ return REGISTER; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 221 "giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 222 "giscanner/scannerlexer.l"
{ return RETURN; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 223 "giscanner/scannerlexer.l"
{ return SHORT; }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 224 "giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 225 "giscanner/scannerlexer.l"
{ return SIZEOF; }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 226 "giscanner/scannerlexer.l"
{ return STATIC; }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 227 "giscanner/scannerlexer.l"
{ return STRUCT; }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 228 "giscanner/scannerlexer.l"
{ return SWITCH; }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 229 "giscanner/scannerlexer.l"
{ return TYPEDEF; }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 230 "giscanner/scannerlexer.l"
{ return UNION; }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 231 "giscanner/scannerlexer.l"
{ return UNSIGNED; }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 232 "giscanner/scannerlexer.l"
{ return VOID; }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 233 "giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 234 "giscanner/scannerlexer.l"
{ return WHILE; }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 236 "giscanner/scannerlexer.l"
{ return check_identifier(scanner, yytext); }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 238 "giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 239 "giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 240 "giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 242 "giscanner/scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 243 "giscanner/scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 152:
/* rule 152 can match eol */
YY_RULE_SETUP
#line 245 "giscanner/scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 153:
/* rule 153 can match eol */
YY_RULE_SETUP
#line 246 "giscanner/scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 154:
/* rule 154 can match eol */
YY_RULE_SETUP
#line 248 "giscanner/scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 155:
/* rule 155 can match eol */
YY_RULE_SETUP
#line 249 "giscanner/scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 251 "giscanner/scannerlexer.l"
{ print_error(scanner); }
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 253 "giscanner/scannerlexer.l"
ECHO;
	YY_BREAK
#line 2242 "scannerlexer.c"
			case YY_STATE_EOF(INITIAL):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	yy_size_t number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (yy_size_t) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((int) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 677 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    
	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 677 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 676);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = (yy_size_t)size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
			(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    yyfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 253 "giscanner/scannerlexer.l"



static int
yywrap (void)
{
  return 1;
}

static void
parse_comment (GISourceScanner *scanner)
{
  int c1, c2;
  GString *string = NULL;
  GISourceComment *comment;
  int comment_lineno;
  int skip = FALSE;

  c1 = input();
  c2 = input();

  if (c2 != EOF && (c1 == '*' && c2 != '*' && c2 != '/')) {
    /*
     * Store GTK-Doc comment blocks,
     * starts with one '/' followed by exactly two '*' and not followed by a '/'
     */
    if (!g_hash_table_contains (scanner->files, scanner->current_file)) {
        skip = TRUE;
    } else {
        string = g_string_new (yytext);
    }

    comment_lineno = lineno;

    while (c2 != EOF && !(c1 == '*' && c2 == '/'))
      {
        if (!skip)
          g_string_append_c (string, c1);

        if (c1 == '\n')
          lineno++;

        c1 = c2;
        c2 = input();
      }

    if (skip) {
        return;
    }

    g_string_append (string, "*/");

    comment = g_slice_new (GISourceComment);
    comment->comment = g_string_free (string, FALSE);
    comment->line = comment_lineno;
    comment->filename = g_file_get_parse_name (scanner->current_file);

    gi_source_scanner_take_comment (scanner, comment);
  } else {
    /*
     * Ignore all other comment blocks
     */
    while (c2 != EOF && !(c1 == '*' && c2 == '/'))
      {
        if (c1 == '\n')
          lineno++;

        c1 = c2;
        c2 = input();
      }

    return;
  }
}

static int
check_identifier (GISourceScanner *scanner,
		  const char  *s)
{
	/*
	 * This function checks if `s' is a type name or an
	 * identifier.
	 */

	if (gi_source_scanner_is_typedef (scanner, s)) {
		return TYPEDEF_NAME;
	} else if (strcmp (s, "__builtin_va_list") == 0) {
		return TYPEDEF_NAME;
	}

	return IDENTIFIER;
}

/* taken from glib/gfileutils.c */
#if defined(MAXPATHLEN)
#define G_PATH_LENGTH MAXPATHLEN
#elif defined(PATH_MAX)
#define G_PATH_LENGTH PATH_MAX
#elif defined(_PC_PATH_MAX)
#define G_PATH_LENGTH sysconf(_PC_PATH_MAX)
#else
#define G_PATH_LENGTH 2048
#endif

static inline char *
_realpath (const char *path)
{
#ifndef _WIN32
  char buffer[G_PATH_LENGTH];

  return realpath (path, buffer) ? g_strdup (buffer) : NULL;
#else
  /* We don't want to include <windows.h> as it clashes horribly
   * with token names from scannerparser.h. So just declare
   * GetFullPathNameA() here unless we already defined it, like
   * in giscanner.c.
   */
#ifndef USE_WINDOWS
  extern __stdcall GetFullPathNameA(const char*, int, char*, char**);
#endif
  char *buffer;
  char dummy;
  int rc, len;

  rc = GetFullPathNameA (path, 1, &dummy, NULL);
  if (rc == 0)
    {
      /* Weird failure, so just return the input path as such */
      return g_strdup (path);
    }

  len = rc + 1;
  buffer = g_malloc (len);

  rc = GetFullPathNameA (path, len, buffer, NULL);
  if (rc == 0 || rc > len)
    {
      /* Weird failure again */
      g_free (buffer);
      return g_strdup (path);
    }
  return buffer;
#endif
}

/*
 * # linenum "filename" flags
 *  See http://gcc.gnu.org/onlinedocs/cpp/Preprocessor-Output.html
 **/

static void
process_linemarks (GISourceScanner *scanner, gboolean has_line)
{
	char escaped_filename[1025];
	char *filename;
	char *real;

	if (has_line)
		sscanf(yytext, "#line %d \"%1024[^\"]\"", &lineno, escaped_filename);
	else
		sscanf(yytext, "# %d \"%1024[^\"]\"", &lineno, escaped_filename);

	filename = g_strcompress (escaped_filename);

        real = _realpath (filename);
        if (real)
          {
            g_free (filename);
            filename = real;
          }

        if (scanner->current_file)
          g_object_unref (scanner->current_file);
	scanner->current_file = g_file_new_for_path (filename);
	g_free (filename);
}

/*
 * This parses a macro which is ignored, such as
 * __attribute__((x)) or __asm__ (x)
 */
static int
parse_ignored_macro (void)
{
	int c;
	int nest;

	while ((c = input ()) != EOF && isspace (c))
		;
	if (c != '(')
		return FALSE;

	nest = 0;
	while ((c = input ()) != EOF && (nest > 0 || c != ')')) {
		if (c == '(')
			nest++;
		else if (c == ')')
			nest--;
		else if (c == '"') {
			while ((c = input ()) != EOF && c != '"') {
				if (c == '\\')
					c = input ();
			}
		} else if (c == '\'') {
			c = input ();
			if (c == '\\')
				c = input ();
			else if (c == '\'')
				return FALSE;
			c = input ();
			if (c != '\'')
				return FALSE;
		} else if (c == '\n')
			lineno++;
	}

	return TRUE;
}

static void
parse_trigraph (GISourceScanner *scanner)
{
	char **items;
	char *start, *end;
	int i;

	start = g_strstr_len (yytext, yyleng, "<");
	g_assert (start != NULL);
	end = g_strstr_len (yytext, yyleng, ">");
	g_assert (end != NULL);
	*end = '\0';
	items = g_strsplit (start + 1, ",", 0);
	for (i = 0; items[i] != NULL; i++) {
		char *item = items[i];
		g_strstrip (item);
		if (strcmp (item, "public") == 0)
			scanner->private = FALSE;
		else if (strcmp (item, "private") == 0)
			scanner->private = TRUE;
		else if (strcmp (item, "flags") == 0)
			scanner->flags = TRUE;
	}
	g_strfreev (items);
}

static void
print_error (GISourceScanner *scanner)
{
  if (yytext[0]) {
    char *filename = g_file_get_parse_name (scanner->current_file);
    fprintf(stderr, "%s:%d: unexpected character `%c'\n", filename, lineno, yytext[0]);
    g_free (filename);
  }
}

